# 变更日志

所有本项目的重要变更都将记录在此文件中。

格式基于 [Keep a Changelog](https://keepachangelog.com/zh-CN/1.0.0/)，
并且本项目遵循 [语义化版本](https://semver.org/lang/zh-CN/) 规范。

## [0.2.0] - 2025-07-23

### 新增

- 🏗️ **高级接口** - 添加了企业级的高级接口
    - ✨ `ReactiveDict` - 响应式字典，支持嵌套结构和动态键
    - ✨ `ReadOnlyView` - 只读视图，提供结构化的数据访问保护
    - 🎯 支持与 `TypedDict` 和 `Protocol` 结合使用，获得完整类型提示
- ⚡ **执行器配置系统** - 灵活的回调执行控制
    - 🎛️ 全局执行器配置：支持 `'asyncio'` 和自定义 `ThreadPoolExecutor`
    - 🔴 `subscribe_immediate=True` - 强制在当前线程同步执行（忽略执行器配置）
    - 🟦 `subscribe_sequential=True` - 保证回调按注册顺序执行
- 📚 **完整的文档重构**
    - 🔧 明确区分底层接口（Ref/effect）和高级接口（ReactiveDict/ReadOnlyView）
    - 📖 详细的使用场景推荐和最佳实践
    - 🚀 新增快速入门示例和完整功能演示
    - ⚡ 同步、异步、多线程使用方式详解

### 修复

- 🐛 **关键 Bug 修复** - 修复了 `subscribe_sequential` 执行顺序不保证的问题
    - 将 `_subscribers` 从 `set()` 改为 `list()` 以保持注册顺序
    - 确保 `subscribe_sequential=True` 时回调严格按注册顺序执行
- 🔒 增强线程安全保障
    - 改进了并发订阅/取消订阅操作的安全性
    - 优化了多线程环境下的锁机制

### 变更

- 📈 **测试覆盖率大幅提升** - 从 62.8% 提升到 90.53%
    - 新增 145+ 个测试用例
    - 全面覆盖所有新功能和边界情况
    - 包含并发、异步、错误处理等高级测试场景
- 🎯 **API 增强** - 扩展了现有接口功能
    - `ReadOnlyRef` 现在支持从 `Ref` 创建只读引用
    - 改进了错误处理和类型验证
    - 增强了 `__repr__` 方法的可读性

### 技术细节

- 🔧 新增执行器配置 API：`Ref.configure_sync_task_executor()`
- 🌲 `ReactiveDict` 支持无限层级的嵌套结构自动转换
- 👁️ `ReadOnlyView` 递归将所有值转换为 `ReadOnlyRef`，提供完整的只读保护
- 📊 优化了内存使用和性能表现
- 🧪 添加了大量示例文件：`examples/quick_start.py`、`examples/documentation_demo.py` 等

## [0.1.0] - 2025-07-18

### 新增

- 🎉 初始版本发布
- ✨ 实现了 `Ref` 响应式数据容器
    - 支持泛型类型提示
    - 线程安全的订阅者管理
    - 自动依赖收集
- ✨ 实现了 `effect` 装饰器
    - 支持同步和异步函数
    - 自动建立依赖关系
    - 支持手动停止效果
- ✨ 多环境支持
    - 多线程环境支持（使用 `threading.local`）
    - 异步环境支持（使用 `contextvars`）
- 📝 完整的类型提示支持
- 📚 详细的文档和示例
- 🧪 基础项目结构和配置文件

### 技术细节

- 使用 `threading.Lock` 确保订阅者集合的线程安全
- 使用 `contextvars` 在异步环境中管理当前效果
- 支持 Python 3.8+ 版本
- 完整的 `pyproject.toml` 配置
- MIT 许可证

---

## 版本说明

### 版本号规则

- **主版本号**：不兼容的 API 修改
- **次版本号**：向下兼容的功能性新增
- **修订号**：向下兼容的问题修正

### 变更类型

- **新增** - 新功能
- **变更** - 对现有功能的变更
- **弃用** - 即将移除的功能
- **移除** - 已移除的功能
- **修复** - 问题修复
- **安全** - 安全相关的修复
